@@ -215,11 +215,11 @@ int main(int argc, char *argv[])
 #endif //
 
 #ifndef BUILD_VERSION
-#define BUILD_VERSION "24.07.20251108"
+#define BUILD_VERSION "24.07.20260103"
 #endif //
 
     qDebug() << "buildVersionString: " << BUILD_VERSION;
-    qDebug() << "buildDateString: " << QString("%1 %2").arg("Nov 08 2025").arg("01:54:49");
+    qDebug() << "buildDateString: " << QString("%1 %2").arg("Jan 03 2026").arg("02:00:36");
 
     qDebug() << "buildQtVersionString: " << QString("Qt %1.%2.%3").arg(QT_VERSION_MAJOR).arg(QT_VERSION_MINOR).arg(QT_VERSION_PATCH);
     qDebug() << "runtimeQtVersionString: " << qVersion();
@@ -228,7 +228,7 @@ int main(int argc, char *argv[])
     qDebug() << "runtimeFFmpegVersionString: " << av_version_info();
 
     engine.rootContext()->setContextProperty("buildVersionString", BUILD_VERSION);
-    engine.rootContext()->setContextProperty("buildDateString", QString("%1 %2").arg("Nov 08 2025").arg("01:54:49"));
+    engine.rootContext()->setContextProperty("buildDateString", QString("%1 %2").arg("Jan 03 2026").arg("02:00:36"));
 
     engine.rootContext()->setContextProperty("buildQtVersionString", QString("Qt %1.%2.%3").arg(QT_VERSION_MAJOR).arg(QT_VERSION_MINOR).arg(QT_VERSION_PATCH));
     engine.rootContext()->setContextProperty("runtimeQtVersionString", qVersion());
